import React, { Component } from 'react';
import autoBind from 'react-autobind';
import { connect } from 'react-redux';
import './CompaniesScreen.css';
import * as companiesActions from '../store/companies/actions';
import * as companiesSelectors from '../store/companies/reducer';
import ListRow from '../components/ListRow';
import { withRouter } from 'react-router-dom'
import licenseManagementService from '../services/licenseManagement';
import List from '../components/List'


class CompaniesScreen extends Component {

    constructor(props){
        super(props);
        autoBind(this);

        this.state ={
            searchTerm: '',
            initialCompanyList: [],
            companyList: []
        };
    }

    componentDidMount() {

        licenseManagementService.getCompanies().then( company => {
            this.setState({
                companyList: company,
                initialCompanyList: company
            })
        });



    }

    doFilterList(event){
        let updateCompanyList = this.state.initialCompanyList;
        updateCompanyList = this.filterHelper(event.target.value);

        console.log('My Filtered List: ' +  JSON.stringify(updateCompanyList));

        this.setState({companyList: updateCompanyList});
    }

    // filterHelper = (value) => {
    //     let newList = [];
    //     this.state.initialCompanyList.map(function(item) {
    //         if (item.companyName.toLowerCase().indexOf(value.toLowerCase()) !== -1) {
    //             newList.push(item);
    //         }
    //     })
    //
    //     return newList;
    // }

    filterHelper(value){
        let newList = [];
        this.state.initialCompanyList.map(function(item) {
            if (item.companyName.toLowerCase().indexOf(value.toLowerCase()) !== -1) {
                newList.push(item);
            }
        })

        return newList;
    }

    render() {

        if(!this.state.companyList) return this.renderLoading();

        return(
            <div className="TopicsScreen">
                <div className="filter-list">
                    <input type="text" placeholder="Search" onChange={this.doFilterList}/>
                    <List items={this.state.companyList}/>
                </div>
            </div>
        );

    }

    renderLoading() {
        return (
            <p>Loading...</p>
        );
    }

    renderRow(company) {
        return(
                <ListRow
                    rowId={company.companyName}
                    onClick={this.onRowClick}>
                    <h3>{company.companyName}</h3>
                    <p>{company.licenseKey}</p>
                </ListRow>
        );
   }

    onRowClick(companyName) {
        this.props.dispatch(companiesActions.selectCompany(companyName));
    }
}

export default withRouter(connect()(CompaniesScreen));
